//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[FuroChanceShantenArgs](index.md)/[allowKuikae](allow-kuikae.md)

# allowKuikae

[common]\
val [allowKuikae](allow-kuikae.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false

#### Parameters

common

| | |
|---|---|
| allowKuikae | 是否允许食替 |
